summaryrefslogtreecommitdiff
path: root/__init__.py
diff options
context:
space:
mode:
authorDavid Douard <david.douard@logilab.fr>2013-06-17 18:09:03 +0200
committerDavid Douard <david.douard@logilab.fr>2013-06-17 18:09:03 +0200
commitde948487c55093839c6c022bff5f45b195637c3d (patch)
treeea29aee5cf6a39fd566a2a5008bef682813d5a39 /__init__.py
parent71454b097693d33daceb5d83925abfc62c9e12ec (diff)
downloadastroid-de948487c55093839c6c022bff5f45b195637c3d.tar.gz
rename the project astroid
Diffstat (limited to '__init__.py')
-rw-r--r--__init__.py40
1 files changed, 20 insertions, 20 deletions
diff --git a/__init__.py b/__init__.py
index c43e793..e3b6e3b 100644
--- a/__init__.py
+++ b/__init__.py
@@ -1,20 +1,20 @@
# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This file is part of logilab-astng.
#
# logilab-astng is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# logilab-astng is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License along
-# with logilab-astng. If not, see <http://www.gnu.org/licenses/>.
+# with astroid. If not, see <http://www.gnu.org/licenses/>.
"""Python Abstract Syntax Tree New Generation
The aim of this module is to provide a common base representation of
@@ -25,7 +25,7 @@ governed by pylint's needs.
It extends class defined in the python's _ast module with some
additional methods and attributes. Instance attributes are added by a
builder object, which can either generate extended ast (let's call
-them astng ;) by visiting an existent ast tree or by inspecting living
+them astroid ;) by visiting an existent ast tree or by inspecting living
object. Methods are added by monkey patching ast classes.
Main modules are:
@@ -33,11 +33,11 @@ Main modules are:
* nodes and scoped_nodes for more information about methods and
attributes added to different node classes
* the manager contains a high level object to get astng trees from
source files and living objects. It maintains a cache of previously
constructed tree for quick access
* builder contains the class responsible to build astng trees
"""
__doctype__ = "restructuredtext en"
@@ -45,26 +45,26 @@ import sys
# WARNING: internal imports order matters !
-# make all exception classes accessible from astng package
-from logilab.astng.exceptions import *
+# make all exception classes accessible from astroid package
+from astroid.exceptions import *
-# make all node classes accessible from astng package
-from logilab.astng.nodes import *
+# make all node classes accessible from astroid package
+from astroid.nodes import *
# trigger extra monkey-patching
-from logilab.astng import inference
+from astroid import inference
# more stuff available
-from logilab.astng import raw_building
-from logilab.astng.bases import YES, Instance, BoundMethod, UnboundMethod
-from logilab.astng.node_classes import are_exclusive, unpack_infer
-from logilab.astng.scoped_nodes import builtin_lookup
+from astroid import raw_building
+from astroid.bases import YES, Instance, BoundMethod, UnboundMethod
+from astroid.node_classes import are_exclusive, unpack_infer
+from astroid.scoped_nodes import builtin_lookup
# make a manager instance (borg) as well as Project and Package classes
-# accessible from astng package
-from logilab.astng.manager import ASTNGManager, Project
-MANAGER = ASTNGManager()
-del ASTNGManager
+# accessible from astroid package
+from astroid.manager import AstroidManager, Project
+MANAGER = AstroidManager()
+del AstroidManager
# load brain plugins
from os import listdir
@@ -1,20 +1,20 @@
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
-# This file is part of logilab-astng.
+# This file is part of astroid.
#
@@ -1,20 +1,20 @@
#
-# logilab-astng is free software: you can redistribute it and/or modify it
+# astroid is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation, either version 2.1 of the License, or (at your
@@ -1,20 +1,20 @@
# option) any later version.
#
-# logilab-astng is distributed in the hope that it will be useful, but
+# astroid is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
@@ -33,11 +33,11 @@ Main modules are:
* nodes and scoped_nodes for more information about methods and
attributes added to different node classes
-* the manager contains a high level object to get astng trees from
+* the manager contains a high level object to get astroid trees from
source files and living objects. It maintains a cache of previously
constructed tree for quick access
@@ -33,11 +33,11 @@ Main modules are:
source files and living objects. It maintains a cache of previously
constructed tree for quick access
-* builder contains the class responsible to build astng trees
+* builder contains the class responsible to build astroid trees
"""
__doctype__ = "restructuredtext en"